@@ -1,5 +1,5 @@
 package Playwright;
-$Playwright::VERSION = '0.011';
+$Playwright::VERSION = '0.012';
 use strict;
 use warnings;
 
@@ -316,7 +316,7 @@ Playwright - Perl client for Playwright
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -431,6 +431,9 @@ L<https://playwright.dev/docs/api/class-page#pageevalselector-pagefunction-arg>
 You will have to refer to the arguments array as described here:
 L<https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Functions/arguments>
 
+You can also pass Playwright::ElementHandle objects as returned by the select() and selectMulti() routines.
+They will be correctly translated into DOMNodes as you would get from the querySelector() javascript functions.
+
 =head3 example of evaluate()
 
     # Read the console
